use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
drolsky
DROLSKY
DROLSKY's
PayPal
Rolsky
Rolsky's
afterwards
Anno
BCE
bian
ccc
cccc
ccccc
CLDR
conformant
CPAN
DATETIME
DateTime
Datetime
datetime
datetime's
DateTimes
Datetimes
datetimes
decrement
dian
Domini
durations
eee
EEEE
eeee
EEEEE
eeeee
fallback
Flávio
formatter
Formatters
GGGG
GGGGG
Glock
Hant
hh
iCal
IEEE
ji
Liang
Liang's
LLL
LLLL
LLLLL
Measham
Measham's
MMM
MMMM
MMMMM
mutiplication
na
namespace
ni
nitty
other's
POSIX
proleptic
QQQ
qqq
QQQQ
qqqq
Rata
sexagesimal
Soibelmann
Storable
SU
subclasses
Tsai
TW
TZ
UTC
uu
VVVV
vvvv
wiki
YAPCs
yy
yyyy
yyyyy
zh
ZZZZ
zzzz
ZZZZZ
Dave
autarch
Ben
Bennett
fiji
Christian
Hansen
chansen
Daisuke
Maki
dmaki
David
Wheeler
david
Doug
Bell
madcityzen
fglock
Gregory
Oschwald
oschwald
Iain
Truskett
deceased
Jason
McIntosh
jmac
Joshua
Hoblitt
jhoblitt
Karen
Etheridge
ether
Michael
Conrad
mike
Nick
Tonkin
1nickt
Ovid
curtis_ovid_poe
Ricardo
Signes
rjbs
Richard
Bowen
bowen
Ron
Hill
rkhill
viviparous
lib
Conflicts
Duration
Helpers
Infinite
LeapSecond
PP
PPExtra
